// ===========================================================================
//	LAGAProgressIndicator.h
// ===========================================================================
//	Apple Grayscale Appearance compliant Determinate progress indicator control
//	Copyright  1996 Chrisoft (Christophe ANDRES)  All rights reserved.
//
//	You may use this source code in any application (commercial, shareware, freeware,
//	postcardware, etc), but not remove this notice (no need to acknowledge the use of
//	this class in the about box)
//	You may not sell this source code in any form. This source code may be placed on 
//	publicly accessable archive sites and source code disks. It may not be placed on 
//	profit archive sites and source code disks without the permission of the author, 
//	Christophe ANDRES.
//	
//	    This source code is distributed in the hope that it will be useful,
//	    but WITHOUT ANY WARRANTY; without even the implied warranty of
//	    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
//	If you make any change or improvement on this class, please send the improved/changed
//	version to : chrisoft@calva.net or Christophe ANDRES
//                                     20, rue Prosper Mrime
//                                     67100 STRASBOURG
//                                     FRANCE
//
// ===========================================================================
//	LAGAProgressIndicator.cp			<- double-click + Command-D to see class implementation
//
//	LAGAProgressIndicator is my implementation of the Apple Grayscale Appearance for System 7.5
//		determinate progress indicator.
//		Use the IncrementValue or SetValue methods to update the progress indicator
//
//		This class requires AGAColors.cp to be present in your project
//
//		Version : 1.2
//
//		Change History (most recent first, date in US form : mm/dd/yy):
//
//						06/30/96	ca		Public release of version 1.2
//						06/04/96	ca		added RegisterClass method for easy registry
//														Added guard macros in header files
//														Increased version to 1.2
//						05/21/96	ca		class made available by Christophe ANDRES <chrisoft@calva.net>
//														(version 1.1)
//
//		To Do:
//

#ifndef _H_LAGAProgressIndicator
#define _H_LAGAProgressIndicator
#pragma once

#include <LPane.h>

class	LAGAProgressIndicator : public LPane
{
	public		:
		enum { class_ID = 'AGA6' };
		static void RegisterClass ();																																		//	<06/04/96	ca>
		static LAGAProgressIndicator* CreateAGAProgressIndicatorStream (LStream* inStream);
		
		LAGAProgressIndicator ();
		
		LAGAProgressIndicator (LStream *inStream);
		
		LAGAProgressIndicator (const LAGAProgressIndicator &inOriginal);
		
		LAGAProgressIndicator (const SPaneInfo &inPaneInfo, Int32 inInitialValue, Int32 inMinValue, Int32 inMaxValue);
		
		virtual Int32 GetValue () const { return mValue; };
		
		virtual void SetValue (Int32 inValue);
		
		virtual void IncrementValue (Int32 inIncrement = 1);
	
		Int32 GetMinValue () const { return mMinValue; };
		
		virtual void SetMinValue (Int32 inMinValue);
	
		Int32 GetMaxValue () const { return mMaxValue; };
		
		virtual void SetMaxValue (Int32 inMaxValue);
		
	protected	:
		virtual void DrawSelf ();

		Int32 mValue;
		Int32 mMinValue;
		Int32 mMaxValue;
};

#endif
